use strict; use warnings;
BEGIN {
  unless(eval q{ use 5.006; 1}) {
    print "Perl 5.006 or better required\n";
    exit;
  }
}

# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.006.
use strict;
use warnings;

use Module::Build 0.3601;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.3601"
  },
  "configure_requires" => {
    "Module::Build" => "0.3601",
    "perl" => "5.006"
  },
  "dist_abstract" => "Installer for libarchive",
  "dist_author" => [
    "Graham Ollis <plicease\@cpan.org>"
  ],
  "dist_name" => "Alien-Libarchive-Installer",
  "dist_version" => "0.15",
  "license" => "perl",
  "module_name" => "Alien::Libarchive::Installer",
  "recursive_test_files" => 1,
  "requires" => {
    "ExtUtils::CBuilder" => 0,
    "File::ShareDir" => 0,
    "HTTP::Tiny" => 0,
    "perl" => "5.006"
  },
  "share_dir" => {
    "dist" => "share"
  },
  "test_requires" => {
    "Test::More" => "0.94",
    "perl" => "5.006"
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.3601",
  "Test::More" => "0.94",
  "perl" => "5.006"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
